SoundDrizzle
============

This is nothing more than a simple downloader for SoundCloud so that you can listen to your favorite tracks offline.

Be a nice person and don't abuse the program for mass downloading.

Usage (please consult drizzle --help for more info)::
    drizzle <url> [<output>]